==> qmmp_0.8.2.orig.tar.bz2: qmmp-0.8.2/src/plugins/Input/opus/translations/opus_plugin_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lt">
<context>
    <name>DecoderOpusFactory</name>
    <message>
        <location filename="../decoderopusfactory.cpp" line="48"/>
        <source>Opus Plugin</source>
        <translation>Opus Įskiepis</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="51"/>
        <source>Ogg Opus Files</source>
        <translation>Ogg Opus Bylos</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="122"/>
        <source>About Opus Audio Plugin</source>
        <translation>Apie Opus Audio Įskiepį</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="123"/>
        <source>Qmmp Opus Audio Plugin</source>
        <translation>Qmmp Opus Audio Įskiepis</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="124"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Sukūrė: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="125"/>
        <source>This plugin includes code from TagLib library</source>
        <translation>Įskiepyje yra kodo iš TagLib bibliotekos </translation>
    </message>
</context>
<context>
    <name>OpusMetaDataModel</name>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="51"/>
        <source>Length</source>
        <translation>Trukmė</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="52"/>
        <source>Sample rate</source>
        <translation>Dažnis</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="52"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="53"/>
        <source>Channels</source>
        <translation>Kanalai</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="54"/>
        <source>Bitrate</source>
        <translation>Kokybė</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="54"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="55"/>
        <source>File size</source>
        <translation>Bylos dydis</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="55"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
</context>
</TS>

==> qmmp-0.12.4.tar.bz2: qmmp-0.12.4/src/plugins/Input/opus/translations/opus_plugin_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lt">
<context>
    <name>DecoderOpusFactory</name>
    <message>
        <location filename="../decoderopusfactory.cpp" line="43"/>
        <source>Opus Plugin</source>
        <translation>Opus Įskiepis</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="46"/>
        <source>Ogg Opus Files</source>
        <translation>Ogg Opus Bylos</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="122"/>
        <source>About Opus Audio Plugin</source>
        <translation>Apie Opus Audio Įskiepį</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="123"/>
        <source>Qmmp Opus Audio Plugin</source>
        <translation>Qmmp Opus Audio Įskiepis</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="124"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Sukūrė: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="125"/>
        <source>This plugin includes code from TagLib library</source>
        <translation>Įskiepyje yra kodo iš TagLib bibliotekos </translation>
    </message>
</context>
<context>
    <name>OpusMetaDataModel</name>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="50"/>
        <source>Version</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
